@@ -4,11 +4,13 @@
 
 __author__ = """Ross A. Beyer"""
 __email__ = 'rbeyer@seti.org'
-__version__ = '1.6.0'
+__version__ = '1.7.0'
 
 from .kalasiris import *                      # noqa: F401,F403
 from .k_funcs import *                        # noqa: F401,F403
 from .Histogram import Histogram              # noqa: F401
 from .PathSet import PathSet                  # noqa: F401
+import kalasiris.cube                         # noqa: F401
 import kalasiris.cubenormfile                 # noqa: F401
 import kalasiris.fromlist                     # noqa: F401
+import kalasiris.specialpixels                # noqa: F401
